@@ -12,12 +12,15 @@ use Google::Adwords::Business;
 use Google::Adwords::StatsRecord;
 use Google::Adwords::Image;
 use Google::Adwords::ApiError;
+
+use Google::Adwords::LanguageTarget;
 use Google::Adwords::GeoTarget;
 use Google::Adwords::CityTargets;
 use Google::Adwords::CountryTargets;
 use Google::Adwords::MetroTargets;
 use Google::Adwords::RegionTargets;
 use Google::Adwords::ProximityTargets;
+use Google::Adwords::Circle;
 
 use HTML::Entities;
 
